\name{bost}
\title{Bonferroni corrected one-sample multiple t-Test}
\usage{
bost(testvec, groupvec, [cutpoints = NULL], alpha = 0.05)
bostd(testvec, groupvec, alpha = 0.05)
bostc(testvec, groupvec, cutpoints = NULL, alpha = 0.05)
}
\alias{bost}
\arguments{
  \item{testvec}{a numeric vector of observations.}
  \item{groupvec}{a vector of dummy variables for grouping.}
  \item{cutpoints}{a vector of cutpoints for using levels of the
    values of observations in \code{groupvec} to form groups.}
  \item{alpha}{overall Type I error rate.}
}
\description{
  \code{bost} performs multiple one sample t-tests on a vector of observations.
  The vector of observations is divided into groups either by dummy
  variable levels in \code{groupvec} or if \code{cutpoints} is specified,
  by forming groups by ranges of values in \code{groupvec} defined by the
  values in \code{cutpoints} (see examples).  \code{bost} calls \code{bostd}
  for dummy variable grouping or \code{bostc} for range grouping.
}
\value{
  The final list returned by \code{t.test} is returned invisibly.
}
\seealso{\code{select.range}}
\examples{
> testvec<-c(2,4,3,5,4,5,7,6,4,5,6,8,7,9,8)
> groupvec<-c(1,1,1,1,1,2,2,2,2,2,3,3,3,3,3)
> bost(testvec,groupvec) # 

> agevec<-c(10,13,14,25,29,32,34,45,48,55,62,67,69,70,74)
> agecut<-c(0,30,30,60,60,100)
> bost(testvec,agevec,agecut)

Multiple one sample t-test (continuous)  -  Critical t for 3 tests = 0.0167 

Overall mean = 5.533 

Range              Mean         t        df         p
  0 -  30           3.6    -3.792         4    0.0192
 30 -  60           5.4    -0.261         4    0.8066
 60 - 100           7.6     4.053         4    0.0154*
}
